# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.api_success_response import ApiSuccessResponse

class TestApiSuccessResponse(unittest.TestCase):
    """ApiSuccessResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSuccessResponse:
        """Test ApiSuccessResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSuccessResponse`
        """
        model = ApiSuccessResponse()
        if include_optional:
            return ApiSuccessResponse(
                status = 'success',
                message = '',
                data = None
            )
        else:
            return ApiSuccessResponse(
                message = '',
        )
        """

    def testApiSuccessResponse(self):
        """Test ApiSuccessResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
