# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class WebhookTopics(str, Enum):
    """
    WebhookTopics
    """

    """
    allowed enum values
    """
    CONVERSATION_DOT_ADMIN_DOT_REPLIED = 'conversation.admin.replied'
    CONVERSATION_DOT_USER_DOT_REPLIED = 'conversation.user.replied'
    CONVERSATION_DOT_USER_DOT_CREATED = 'conversation.user.created'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WebhookTopics from a JSON string"""
        return cls(json.loads(json_str))


