# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.conversation import Conversation

class TestConversation(unittest.TestCase):
    """Conversation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Conversation:
        """Test Conversation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Conversation`
        """
        model = Conversation()
        if include_optional:
            return Conversation(
                type = '',
                id = '',
                part_type = '',
                body = None,
                created_at = 56,
                updated_at = 56,
                notified_at = 56,
                assigned_to = None,
                author = ivyanalytics.models.author.Author(
                    id = '', 
                    type = '', 
                    name = null, 
                    email = '', ),
                attachments = [
                    null
                    ],
                external_id = None,
                redacted = True
            )
        else:
            return Conversation(
                type = '',
                id = '',
                part_type = '',
                created_at = 56,
                updated_at = 56,
                notified_at = 56,
                author = ivyanalytics.models.author.Author(
                    id = '', 
                    type = '', 
                    name = null, 
                    email = '', ),
                attachments = [
                    null
                    ],
                redacted = True,
        )
        """

    def testConversation(self):
        """Test Conversation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
