# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.conversation_data_schema import ConversationDataSchema

class TestConversationDataSchema(unittest.TestCase):
    """ConversationDataSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConversationDataSchema:
        """Test ConversationDataSchema
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConversationDataSchema`
        """
        model = ConversationDataSchema()
        if include_optional:
            return ConversationDataSchema(
                conversations = [
                    ivyanalytics.models.conversation_schema.ConversationSchema(
                        conversation_id = '', 
                        tenant_id = '', 
                        conversation_created_at = null, 
                        messages = [
                            ivyanalytics.models.message_schema.MessageSchema(
                                id = '', 
                                role = 'user', 
                                body = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        metadata = null, )
                    ],
                created_at = '2024-03-05T07:37:50.187126+00:00'
            )
        else:
            return ConversationDataSchema(
                conversations = [
                    ivyanalytics.models.conversation_schema.ConversationSchema(
                        conversation_id = '', 
                        tenant_id = '', 
                        conversation_created_at = null, 
                        messages = [
                            ivyanalytics.models.message_schema.MessageSchema(
                                id = '', 
                                role = 'user', 
                                body = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        metadata = null, )
                    ],
        )
        """

    def testConversationDataSchema(self):
        """Test ConversationDataSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
