# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.models.webhook_topics import WebhookTopics

class TestWebhookTopics(unittest.TestCase):
    """WebhookTopics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWebhookTopics(self):
        """Test WebhookTopics"""
        # inst = WebhookTopics()

if __name__ == '__main__':
    unittest.main()
