# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501
from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "ivyanalytics"
VERSION = "0.0.b0"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

with open('README.md') as readme:
    readme_content = readme.read()

setup(
    name=NAME,
    version=VERSION,
    description="Ivy Analytics API",
    author="This SDK is used to ingest data into Ivy Analytics.",
    author_email="hello@ivyanalytics.io",
    url="https://www.ivyanalytics.io",
    keywords=["Ivy Analytics", "Conversational Analytics"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description=readme_content,
    package_data={"ivyanalytics": ["py.typed"]},
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",

        # List of supported Python versions
        # Make sure that this is reflected in .github/workflows/python.yml as well
        "Programming Language :: Python",
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',

        "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)
