# coding: utf-8

"""
    Ivy Analytics API

    API for data ingestion

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ivyanalytics.api.intercom_api import IntercomApi


class TestIntercomApi(unittest.TestCase):
    """IntercomApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IntercomApi()

    def tearDown(self) -> None:
        pass

    def test_conversations_v1_intercom_conversations_post(self) -> None:
        """Test case for conversations_v1_intercom_conversations_post

        Conversations
        """
        pass


if __name__ == '__main__':
    unittest.main()
